.. _turboctl:

turboctl
=========

The ``turboctl`` package contains the source code for TurboCtl, and is divided
into the following three subpackages:

.. toctree::
    
    telegram/index.rst
    ui/index.rst
    virtualpump/index.rst

The package also contains these auxiliary modules:

.. toctree::

    hacks.rst
    main.rst

and the following variables:

.. automodule:: turboctl

